| Title: | Time Series Forecasting Using 23 Individual Models |
|---|---|
| Description: | Runs multiple individual time series models, and combines them into an ensembles of time series models. This is mainly used to predict the results of the monthly labor market report from the United States Bureau of Labor Statistics for virtually any part of the economy reported by the Bureau of Labor Statistics, but it can be easily modified to work with other types of time series data. For example, the package was used to predict the winning men's and women's time for the 2024 London Marathon. |
| Authors: | Russ Conte [aut, cre, cph] |
| Maintainer: | Russ Conte <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.5.1 |
| Built: | 2026-05-15 09:16:38 UTC |
| Source: | https://github.com/infinitecuriosity/forecastingensembles |
forecasting—function to perform time series analysis and return the results to the user.
Forecasting( time_series_name, time_series_data, train_amount, number_of_intervals_to_forecast, use_parallel = c("Y", "N"), time_interval = c("Q", "M", "W") )Forecasting( time_series_name, time_series_data, train_amount, number_of_intervals_to_forecast, use_parallel = c("Y", "N"), time_interval = c("Q", "M", "W") )
time_series_name |
the name of the time series in quotation marks |
time_series_data |
a time series |
train_amount |
The amount to use for the training set, such as 0.60 |
number_of_intervals_to_forecast |
the number of intervals, such as months or weeks, that are going to be forecast |
use_parallel |
"Y" or "N" for parallel processing |
time_interval |
user states whether the time interval is quarterly, monthly or weekly. |
A series of summary reports and visualizations to fully describe the time series: Forecast accuracy, forecast numbers, forecast plot, innovation residuals,
best autocorrelation function (ACF), plot of best histogram of residuals, plot of best actual vs predicted, plot of best actual vs trend
plot of best actual vs seasonally adjusted
This is a report of all nonfarm employees in the United States, as reported by the Bureau of Labor Statistics. The report runs from January, 2015 through October, 2024
Oct_2024_all_nonfarmOct_2024_all_nonfarm
An object of class tbl_ts (inherits from tbl_df, tbl, data.frame) with 118 rows and 2 columns.
The month for the subject of the labor survey
The number of people working
@source https://data.bls.gov/dataViewer/view/timeseries/CES0000000001
This is a report of the average hourly pay for all workers in the United States, as reported by the Bureau of Labor Statistics
Oct_2024_avg_hourly_payOct_2024_avg_hourly_pay
An object of class tbl_ts (inherits from tbl_df, tbl, data.frame) with 117 rows and 2 columns.
The month for the subject of the labor survey
The average hourly pay in the United States
@source https://data.bls.gov/dataViewer/view/timeseries/CES0500000003
This is a report of the unemployment rate in the United States, as reported by the Bureau of Labor Statistics
Oct_2024_unemploymentOct_2024_unemployment
An object of class tbl_ts (inherits from tbl_df, tbl, data.frame) with 117 rows and 2 columns.
The month for the subject of the labor survey
The unemployment rate
@source https://data.bls.gov/dataViewer/view/timeseries/LNS14000000